from .__pytransform import pyarmor_runtime

"""
# MixtureMapping

[![Documentation](https://github.com/VK/dash-express-components/workflows/Publish%20release/badge.svg)](https://vk.github.io/mixturemapping-doc)
[![PyPI version](https://badge.fury.io/py/mixturemapping.svg)](https://badge.fury.io/py/mixturemapping)

Train Gaussian Mixture Mappings


## Provides:
  1. Layers to build tensorflow models to map Gaussian mixtures
  2. Tools to compute yield values of Gaussian mixtures in complex binning schemes

## Example
  
    import mixturemapping as mm  
    import tensorflow as tf

    inMeans = tf.keras.Input(shape=(mixN, inputMixM), name="Means", dtype=dataType)
    inStdDevs = tf.keras.Input(shape=(mixN, inputMixM), name="StdDevs", dtype=dataType)
    inWeight = tf.keras.Input(shape=(mixN), name="Weights", dtype=dataType)

    mapModel = tf.keras.Sequential()
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    mapModel.add( tf.keras.layers.Dense(outputMixM))
    y = mapModel(inMeans)

    deltaModel = tf.keras.Sequential()
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(40, activation="relu", kernel_regularizer=regularizers.l2(0.001)) )
    deltaModel.add( tf.keras.layers.Dense(outputMixM))
    yDelta = deltaModel(inMeans)

    covALayer = mm.layers.TrainableCovMatrix(outputMixM, name="CovA")
    covA = covALayer(inMeans)

    mapLayer = mm.layers.GeneralMapping(outputMixM, name="Mapping", dtype=dataType)
    newDist = mapLayer({'means': inMeans, 'y':y, 'yDelta':yDelta, 'stdDevs': inStdDevs, 'weights': inWeight, 'covA': covA})

    distLayer = mm.layers.Distribution(dtype=dataType, regularize_cov_epsilon=0.95)
    dist = distLayer(newDist)

### Developement
```
$ py -m venv env
$ .\env\Scripts\activate
$ pip install -r requirements.txt
```


"""


pyarmor_runtime()
__pyarmor__(__name__, __file__, b'\x50\x59\x41\x52\x4d\x4f\x52\x00\x00\x03\x07\x00\x42\x0d\x0d\x0a\x08\x2d\xa0\x01\x00\x00\x00\x00\x01\x00\x00\x00\x40\x00\x00\x00\x87\x08\x00\x00\x00\x00\x00\x18\x51\x72\x16\xd8\xb1\xfd\xc3\xb8\x8e\x39\x53\xce\xbe\x66\x16\x15\x00\x00\x00\x00\x00\x00\x00\x00\x8e\xdc\xf9\xc4\x94\x90\x01\x58\x5b\x42\x9c\x05\x46\x18\x60\x02\xa3\x08\xcf\xf0\x1b\x0e\xb7\x0a\x11\xfb\x15\xd4\x8f\x87\x3d\xd3\x31\x4d\xf0\x9f\xd2\x10\xaf\xf9\x4b\xc0\x42\x8f\x0b\x62\xa7\x4e\x42\x44\x62\x7c\x08\x32\xc7\x26\xe3\x2a\xda\x35\xf4\xdf\x28\x62\x8f\x35\x7c\x81\x31\x21\x3e\x2b\x10\xd9\x71\xd8\xb8\xbe\xfa\x17\xf9\x39\xe8\x5d\x13\xa8\x76\xe6\x33\x07\x60\xc6\x42\x6e\x13\xda\x04\xf8\x86\x5d\xfb\xe1\xf8\x5e\x3d\xfb\x93\xe5\xfb\x00\xda\x9b\x8c\x2a\x05\x4f\x7a\x4d\x31\xd5\xa9\xeb\xf7\x34\x61\x19\x69\x01\x13\x34\x99\x4c\x20\x5d\x96\x58\x09\xf8\x38\x66\xd5\xb4\x9c\x94\xbe\xe7\xdb\x14\x09\x59\xd0\xeb\xc4\xae\x8f\xbe\xdf\x77\xd8\xdc\x17\xa4\x29\x74\x07\xfd\x8c\x4e\x39\x09\x7d\x21\xb1\x9c\xa6\xa3\x95\x5b\x2c\x17\x8f\x6d\x61\xe6\x64\x85\x30\x65\x6c\x50\x2a\xa5\xb3\xac\xc6\x59\x60\x85\x0c\x00\x7d\x08\x4e\x21\xd5\x3c\x6c\xb8\x27\xea\x90\x21\x9e\xbb\xe5\xec\x73\x9f\x38\x81\xbf\x98\x3b\xcf\x5d\x1f\x22\x1e\x9b\x23\x44\xb7\x29\xd2\x0b\x4f\xda\x34\xf3\x88\x85\xfc\x64\xfe\x41\x34\x6e\x40\x22\x94\xee\x97\xc0\x3f\xee\xc5\x98\xef\x27\x5d\xbe\xec\x47\xea\x13\x0f\x64\xb7\x62\x9b\x00\x35\xa7\x4f\x32\xd4\x43\xe4\x56\xf6\x9b\xa2\xd0\xa5\x70\x8c\xde\xf2\x81\xba\x49\x0e\x7b\x4f\xfb\xbf\x57\x8b\x1c\x0c\x4b\xff\x4a\xb3\x1d\x7c\xd7\xee\x82\x62\x38\x79\x7a\x13\x47\xe7\xa7\x54\xcd\xe9\x81\x0b\xa3\x5e\xaa\x0b\xe8\x27\xb7\x99\x5d\xc4\xc8\x61\x51\xa3\x97\xb6\xb0\x72\xa1\xfc\x26\xa5\x92\x8e\xa5\xe8\xfc\x0b\x8b\x0f\xed\x0b\xf2\x1b\xee\x8b\x0a\x2e\x06\xef\xfb\x57\x21\x0e\xe2\x98\x3f\xc7\x04\x49\xc4\x45\x03\x5b\xc9\x38\x2b\x90\x6c\xbc\x73\x75\xa7\x0a\x79\xe3\x2d\xe0\xb3\xfb\x0a\xb8\x20\x4f\xd0\xaf\xe3\xcc\xd8\x16\xfd\x6e\xca\x88\xba\x96\xc6\x1f\xb1\xed\xcd\x5e\x05\xea\x78\x11\x2e\x6f\x12\xee\xdb\x3b\xd4\x8c\x4a\x68\x32\x15\x29\x17\x64\x77\xbb\x95\xa1\x84\xa6\x3a\x65\x6c\xea\x58\x9c\xb1\x25\x02\xec\x10\x76\x33\x82\x1c\x47\xda\x79\xcc\x8f\x0a\xe2\xab\xe3\x70\x29\x49\x47\xea\x00\xd8\xd7\x86\x98\x6b\x11\xe5\xf0\x8d\xee\x8a\x16\x76\x69\x01\x5d\x9d\x6c\xc6\xb5\x71\x24\x71\x56\x11\x70\x96\x36\x56\xf3\xcc\x1e\x6b\x66\x98\xb9\x0f\xfd\xd4\xc3\xa1\x3e\x60\xe5\x33\xf9\x9d\x72\x17\x10\x1b\xe0\x35\x65\x7a\x44\xba\x18\x38\xcb\x23\x1c\x6e\x34\xec\xe6\xbd\xf9\x54\xde\x85\xa8\xc5\x0c\xe6\x39\x24\x7f\x59\x20\x8f\x95\xc2\xec\xad\xac\x62\xb5\xd0\x6f\x26\x70\x59\xeb\x3e\xbb\x5a\x67\xb7\x97\xdd\xe5\xd7\x4e\x4a\x2d\xc1\x46\x52\x07\x4c\x7e\x6a\x22\xf0\x41\x15\x86\xc0\x8d\x9e\x60\x00\x4a\xb2\xa1\x6c\x25\xe3\x90\xfb\x7c\x7b\x0a\xd1\x28\xae\x48\xf9\x77\x1e\x55\x83\x15\xf3\x2c\x45\xc3\x31\x63\x97\x97\x69\xd4\xfe\x3b\x89\xf7\x94\x39\x7a\xd3\xfa\x29\x33\x58\x83\x7e\x92\x95\xb6\xf6\xc6\x85\xb7\xd8\xe5\x9d\x32\xf6\x60\x82\x14\x19\xac\x2d\xdc\x97\x2d\x7d\xfa\x62\x37\xfe\x17\x02\x0e\xbc\x85\x84\x89\x46\xcd\x0c\x0a\xfc\xcf\xfa\xc2\x56\x2f\xa1\xf5\x9c\xdf\xe7\xc4\x13\xce\x98\x38\x7a\x19\x87\xed\xd9\x3e\x99\x57\xe5\x3c\x88\x0f\x01\xfa\xf6\xdb\x71\x3e\x37\x7d\x00\x6d\x2d\x8f\x8e\x08\x9b\xcb\x05\x82\xcc\xa2\x71\xfe\x10\xf7\x88\x98\xb0\x13\xd9\xdf\x19\xaa\xea\xf3\xaa\xbc\xe2\x0a\x63\x35\x80\xd5\x05\xf2\x6a\x4a\xb7\xab\x3b\xd3\x20\x98\xcc\xf3\x5b\xf7\xb8\x61\x72\xbe\xc4\xda\x8c\xa1\xf3\x6d\x0f\xb6\xda\x97\x9b\x28\x54\x79\xcf\x9b\x1b\x97\xaf\x55\x00\x12\xd7\x75\xf3\x25\x85\xb7\xe8\x2c\xc9\xb8\xd1\x33\x11\xed\x17\x3a\x7f\x73\xaf\x58\x57\x2e\x17\xcf\x4d\x82\x02\x59\x4d\xfe\xfa\xec\x8b\xb9\x34\x73\xc8\x49\x1a\x43\xdc\xaf\xc0\xa5\x3f\x4e\x97\x25\xf6\x91\x06\x7f\xa2\x08\x28\x99\x33\xd0\x0e\x90\x94\x49\x7d\xca\x61\xb7\x67\x1e\x35\x59\x10\x4c\x81\xf8\x2b\x61\x84\x0b\x90\x34\x5b\xb8\x23\xbb\xcb\xa0\x1f\xe5\xec\x02\x32\xa0\x49\xd9\x3d\xad\x5d\x0f\xc5\xb2\x96\xeb\x30\xba\x6d\x76\x9c\xe4\x75\x75\xc8\xd6\x8a\x30\xc6\x81\x7e\xc1\xa6\x1e\x0e\xfc\x02\xc2\x73\x79\x6c\xd6\x60\xd0\xb3\xe8\xbc\x7c\x87\x90\xb4\x0d\xaf\x3c\xe4\x52\x69\x6a\xd4\x20\x18\x29\x4b\x12\xda\x37\x57\x3a\x8f\xaf\x2d\x94\x53\x9b\x4f\xc7\x12\x84\xfd\x59\x28\x4c\x43\x62\xa5\x13\xed\x53\x63\xf9\xa7\x1c\x79\xad\xfa\x74\xc7\xd4\x04\xbb\x81\xd3\x8d\xd5\xee\x73\xd0\xf7\xcc\x50\xc1\xae\xd6\xcf\x33\x25\xa5\xa5\x64\xe8\x9e\xc4\xd3\xcb\xa9\x22\x4a\x3b\x38\xb0\x01\x41\x80\xfc\xae\x9b\x4c\x34\x05\xab\x71\x3d\xdc\x60\x9f\x0a\x1b\xbb\xcd\x98\x9f\x89\x24\x43\x8d\x94\x08\x13\xa8\x99\xa7\xb1\x96\xf8\x03\x3d\x76\x06\xbb\xe9\x1b\x92\xb0\xff\xeb\xaa\x7e\xc7\x25\xcf\xc2\x66\x4f\xf3\xa5\x92\x89\x57\x43\xf1\x3d\x68\x64\xf4\x1f\x16\x57\x2c\x2f\xeb\x4e\x61\xac\xaa\x7e\x03\xa6\xa4\xca\xc9\x49\x9c\x2c\x66\x48\xfe\xf4\x25\x92\x14\x1c\x08\x1b\x40\xb3\x8c\x26\x52\x19\xc8\x22\x5f\x27\x9e\xb6\x84\x4e\xa4\x8f\x71\x48\xa8\xc6\x74\x47\x8c\xf5\xa7\x5b\xb1\xf0\x30\xf5\x6f\xe7\x9a\xa0\x3a\x79\x24\xac\x25\xcd\xd3\xf5\xbc\x3a\x4f\x16\xb8\x29\x12\xd4\xae\x90\x9e\x20\x86\x93\x28\x08\x5e\xf6\x34\xf2\x91\x7b\x86\x5d\x5a\xe7\xfd\xe5\xe6\xb3\x19\xcc\xe2\x6a\x30\x14\x7e\x2e\x98\x02\xfb\xd4\x47\x11\xe9\x7b\x9c\xb6\x95\x4c\x37\x70\x1e\x5a\xa5\xdb\x8f\x4c\x94\xa1\x03\x7d\x84\x61\x31\x04\x6b\x5b\xea\xdc\x2f\x59\x28\xa2\x21\xd8\x96\x9c\xdd\xf4\x57\x13\xbc\x3d\x5a\xe0\x07\xbd\xd4\x77\x02\x36\x2d\xbe\x34\xf1\x53\xf3\x01\x87\x59\xbe\x23\xfd\x15\xf9\xc2\x5f\x0a\x0f\xca\xc1\xd3\x45\x6d\xed\x88\x93\xf2\xae\x81\xe4\x0c\x19\x7a\xc0\xa3\xd7\xe4\xc0\xb1\x72\xd7\xbe\xbf\x0e\xd3\xd7\xe6\xc8\xd9\x63\xad\xd0\xdd\x99\x40\x50\xde\xa2\x46\x29\x9b\x59\x74\x76\x9a\x12\xa6\x19\xb1\x4c\x02\x96\xa2\x8f\x5f\xaf\x7d\xd3\x47\x2e\x05\xb3\x1d\x51\xad\x77\x6d\x8c\x31\x34\x85\xa9\xa5\x36\xb5\xdd\x8b\xe6\xac\xbc\x7f\x38\x67\x36\x91\xa7\x18\x86\x17\x1a\x43\xc2\x20\xcf\x2f\xa9\xf7\xa6\x24\x96\x58\xc2\x1c\x7c\xb2\xb2\x4e\x3f\x6a\xa4\x4b\xe8\x34\xbe\xde\x5c\x9f\xfc\x2a\x3c\x2e\xf6\x2d\x81\x6b\xbc\xe9\x6b\xef\x44\xe4\x63\x37\x15\xdc\x8f\xd1\xab\x3d\xe9\x36\x3c\xce\x1b\x45\xf0\x2b\xf1\xfe\x92\xe5\x3e\xd2\xf0\x90\x9c\xc9\xe8\x9c\x8d\x40\x38\xf5\xee\xa4\xc4\x94\xe6\x16\x0d\x26\x09\x85\x51\x67\xa0\x40\x11\x78\x1a\xce\x6a\x1a\x13\xf5\x36\x24\x86\x75\x89\x1e\xe2\x11\xd6\x7c\x6d\xc2\x80\x73\xb4\x57\x64\x0c\x45\xc9\x4c\x50\x94\xbf\xef\x1b\x57\x9e\x89\x73\x17\x0a\x41\xf1\xda\x97\xad\xc3\x32\xe0\x37\x20\x47\xa7\xa8\xf5\x25\xc3\xc1\x1c\x69\xd8\x58\xa0\xea\x49\xea\xa1\x1a\x85\x16\x8d\x50\xe8\x21\x1e\x89\xef\x0b\x80\xac\xf1\x92\xc7\x70\xa8\x9c\xb6\x6b\x95\x4a\xd4\x48\x3b\xf2\x2a\x33\x56\x79\x09\xe8\x5a\xa5\xbe\xe2\x8b\x4d\xd6\x15\x12\xc8\xb9\xc5\xa7\x26\xeb\x7d\x78\xdf\xc6\x83\x8c\xbe\x34\x8c\x67\x3e\xa2\xe4\xce\x8e\xf2\x79\x3a\xf4\x05\x55\x82\xaa\x26\x03\x03\xa8\x39\x31\x31\xee\x76\x74\x47\x78\x6b\xf4\x38\x7d\xad\x34\xf0\xaf\x43\xc1\x29\x1f\x4d\xe6\xe2\xf7\x07\xdb\x8d\xa8\x7f\x6a\x82\x13\x64\x87\x84\xa0\x1c\x9f\x7b\x07\x32\xf9\xcb\x38\xbc\xce\xf0\xcf\xfb\xc1\x7d\x68\xa5\x95\xb2\x96\xcc\x53\xfa\x8d\xc6\xf2\x04\xe6\xc2\xbd\xed\xf7\x7a\x12\x9f\x0c\x9f\xd9\x4b\x22\xd5\x02\x44\x13\xc5\xb1\xeb\x86\xc7\xef\xd0\x62\xb7\xe9\x2f\xe1\xfa\x36\x2c\xd3\x14\xfe\x42\x59\xaa\xd1\x57\xbd\x3f\x21\x22\x33\x22\x9b\x7b\x20\x7f\x88\xe1\x9b\x09\xb2\xb6\x6c\xb2\x93\xee\x8c\x43\xa2\x59\xb6\x06\xcf\xfe\xba\x9b\x5f\xd5\xbf\x21\x0c\x89\xcf\x3c\x03\xd7\xa6\x6e\x0b\x31\x35\x51\x6d\xff\x83\x24\x28\x55\xbc\x66\xa5\xf0\x0e\x44\xbe\x45\x93\xeb\x8e\x72\xa6\x74\xfa\x20\x4f\x4c\x54\xb5\x99\xda\xc5\x9c\x9a\xd9\x1b\xdd\x65\xba\xc9\xd5\xcc\xe0\xed\x10\x37\xf5\x44\xa4\x3e\x4c\x36\xfc\xa0\xc5\xd9\x20\x8e\xf2\x4a\x42\xc4\x9e\xa8\x86\x93\x38\xf2\x34\x5e\x0e\x6c\x11\xfd\xc4\xe4\x0f\xa0\x0c\xe1\xf3\x59\xec\x8d\xfd\x40\x24\xcd\xd9\x50\x3a\xee\xbc\xd2\xe4\xec\x8c\x23\x0c\x3c\xeb\xf9\x47\xb4\x8e\xa7\xbc\x64\xc7\x25\x66\x87\x91\x23\xfb\xaf\xf9\x59\x34\x48\x3a\xd2\x86\x7a\x03\xa0\x0b\xd5\xee\x3c\xee\xf6\x97\x59\x42\xfa\x08\xb4\x9b\x89\xac\x6b\x55\x29\xce\x4f\x76\x8e\xbc\xdf\xb1\xda\xb8\x23\xb7\xec\xeb\x18\xa9\xab\x36\xb6\x5c\x01\x08\x23\x4e\x10\x89\xe5\xf2\xc6\xc8\x15\x18\x67\x10\x6f\x55\x6e\xd9\x7d\xa8\x28\x51\x05\x96\x2b\x36\x11\x0a\xf0\x2a\xfa\xce\xb8\x82\xaa\xf1\xab\x4d\xab\x79\x82\xb7\xff\x3f\x77\x07\xe4\x83\xcc\xb9\xa1\x95\xe9\x38\x21\xc4\xbc\xb6\xb7\x0a\x08\x4c\xa6\x99\xd3\x09\x85\x9b\x30\xdc\x57\x87\xbc\x25\x5a\x08\x0e\x08\xb3\x61\x7d\x93\xa4\x40\xa4\xc6\xf8\x15\xc4\x82\xa2\x85\xf3\xc8\x2a\x6f\x80\x54\x78\x29\xf7\xa7\xfa\x88\x0b\x5f\x53\x2a\x6b\x6e\xa6\xb9\x83\x38\x9b\x5b\xee\xf6\xf6\xf0\x5b\x36\xc3\x6e\x63\x2e\x7d\x98\x08\x24\xa9\xbe\xe8\x13\x4d\xab\x69\x16\x9e\x84\x72\x13\x01\x24\xb7\x70\x89\x75\x98\x49\xd9\x96\x08\x73\x44\xd8\x53\x60\x02\x63\xdf\x7c\xef\x6d\x87\xfe\x0c\x8b\x06\x91\x67\x2b\x20\xb4\xa5\xa7\x80\x1a\x3c\x7c\x07\x05\x71\xcf\xa0\x3c\xc5\x94\x3f\x64\xcd\x0b\x63\xf8\x33\xe6\x0f\x8d\x0d\x2a\xc6\x00\x14\x2f\x74\x6d\x7f\x0d\xdc\x0f\x1a\xd1\x33\x89\x97\xe7\x6a\x13\xd2\x32\x6e\x75\x8e\x89\xbe\xe6\x57\xe1\x61\x42\x57\x90\xfe\x62\x42\xd6\xe8\x6a\x21\x46\x22\xd1\x1d\x0f\xe3\x0a\xa2\xc0\xe5\xda\x48\x53\x7c\xeb\x48\x8b\x66\x70\x78\xbb\x03\x33\x8c\x9a\x22\x39\x81\x7f\x41\x7b\xef\x03\x8c\xb2\x3d\x59\x44\x4a\x2a\x05\xf3\x8e\xd1\xc0\x3a\xea\xff\x8a\xd0\x28\x87\x13\xf8\x77\x96\xad\xc2\xb7\xda\x5d\x5c\x22\xc8\x57\xff\xbb\xe6\x19\x09', 2)

# cleanup
del pyarmor_runtime

